OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Get ekki skrifað í \"config\" möppuna!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "En ef þú vilt halda config.php skránni einungis til lesanlegri, skaltu setja valkostinn \"config_is_read_only\" á 'true' í henni.",
    "See %s" : "Skoðaðu %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Forritið %1$s er ekki til staðar eða er af útgáfu sem ekki er samhæfð þessum netþjóni. Endilega skoðaðu í forritamöppuna.",
    "Sample configuration detected" : "Fann sýnisuppsetningu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Komið hefur í ljós að sýniuppsetningin var afrituð. Þetta getur skemmt uppsetninguna og er ekki stutt. Endilega lestu hjálparskjölin áður en þú gerir breytingar á config.php",
    "The page could not be found on the server." : "Síðan fannst ekki á netþjóninum.",
    "%s email verification" : "Sannvottun tölvupósts fyrir %s",
    "Email verification" : "Sannvottun tölvupósts",
    "Click the following button to confirm your email." : "Smelltu á eftirfarandi hnapp til að staðfesta tölvupóstfangið þitt.",
    "Click the following link to confirm your email." : "Smelltu á eftirfarandi tengil til að staðfesta tölvupóstfangið þitt.",
    "Confirm your email" : "Staðfestu tölvupóstfangið þitt",
    "Other activities" : "Aðrar athafnir",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education bundle" : "Kennsluvöndull",
    "Enterprise bundle" : "Fyrirtækjavöndull",
    "Groupware bundle" : "Hópvinnsluvöndull",
    "Hub bundle" : "Miðstöðvarvöndull",
    "Public sector bundle" : "Vöndull fyrir opinbera þjónustu",
    "Social sharing bundle" : "Deilivöndull fyrir samfélagsmiðla",
    "PHP %s or higher is required." : "Krafist er PHP %s eða hærra.",
    "PHP with a version lower than %s is required." : "Krafist er PHP útgáfu %s eða lægri.",
    "%sbit or higher PHP required." : "Krafist er PHP %sbita eða hærra.",
    "The following architectures are supported: %s" : "Eftirfarandi tölvukerfi eru studd: %s",
    "The following databases are supported: %s" : "Eftirfarandi gagnagrunnar eru studdir: %s",
    "The command line tool %s could not be found" : "Skipanalínutólið \"%s\" fannst ekki",
    "The library %s is not available." : "Aðgerðasafnið %s er ekki tiltækt.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Krafist er aðgerðasafns %1$s með útgáfu hærri en %2$s - tiltæk útgáfa er %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Krafist er aðgerðasafns %1$s með útgáfu lægri en %2$s - tiltæk útgáfa er %3$s.",
    "The following platforms are supported: %s" : "Eftirfarandi stýrikerfi eru studd: %s",
    "Server version %s or higher is required." : "Krafist er þjóns af útgáfu %s eða hærra.",
    "Server version %s or lower is required." : "Krafist er þjóns af útgáfu %s eða lægri.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi eða hafa fengið sérstaka aðgangsheimild fyrir þessa stillingu",
    "Logged in account must be an admin or sub admin" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi",
    "Logged in account must be an admin" : "Innskráður notandi verður að vera stjórnandi",
    "Wiping of device %s has started" : "Útþurrkun af tækinu %s er byrjuð",
    "Wiping of device »%s« has started" : "Útþurrkun af tækinu »%s« er byrjuð",
    "»%s« started remote wipe" : "»%s« byrjaði fjartengda útþurrkun",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Tækið eða forritið »%s« hefur hafið ferli til að þurrka út fjartengt. Þú munt fá annan tölvupóst þegar ferlinu er lokið",
    "Wiping of device %s has finished" : "Útþurrkun af tækinu %s er lokið",
    "Wiping of device »%s« has finished" : "Útþurrkun af tækinu »%s« er lokið",
    "»%s« finished remote wipe" : "»%s« lauk fjartengdri útþurrkun",
    "Device or application »%s« has finished the remote wipe process." : "Tækið eða forritið »%s« hefur lokið fjartengda útþurrkunarferlinu.",
    "Remote wipe started" : "Fjartengd útþurrkun er byrjuð",
    "A remote wipe was started on device %s" : "Fjartengd útþurrkun var hafin á tækinu %s",
    "Remote wipe finished" : "Fjartengdri útþurrkun er lokið",
    "The remote wipe on %s has finished" : "Fjartengd útþurrkun á %s er lokið",
    "Authentication" : "Auðkenning",
    "Unknown filetype" : "Óþekkt skráategund",
    "Invalid image" : "Ógild mynd",
    "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
    "Files" : "Skrár",
    "View profile" : "Skoða notandasnið",
    "same time" : "sami tími",
    "_%nh_::_%nh_" : ["%nklst","%nklst"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s á undan",
    "%s behind" : "%s á eftir",
    "Local time: %s" : "Staðartími: %s",
    "today" : "í dag",
    "tomorrow" : "á morgun",
    "yesterday" : "í gær",
    "_in %n day_::_in %n days_" : ["eftir %n dag","eftir %n daga"],
    "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
    "next month" : "í næsta mánuði",
    "last month" : "í síðasta mánuði",
    "_in %n month_::_in %n months_" : ["eftir %n mánuð","eftir %n mánuði"],
    "_%n month ago_::_%n months ago_" : ["fyrir %n mánuði","fyrir %n mánuðum"],
    "next year" : "á næsta ári",
    "last year" : "síðasta ári",
    "_in %n year_::_in %n years_" : ["eftir %n ár","eftir %n ár"],
    "_%n year ago_::_%n years ago_" : ["fyrir %n degi síðan","fyrir %n árum síðan"],
    "_in %n hour_::_in %n hours_" : ["eftir %n klukkustund","eftir %n klukkustundir"],
    "_%n hour ago_::_%n hours ago_" : ["fyrir %n klukkustund síðan","fyrir %n klukkustundum síðan"],
    "_in %n minute_::_in %n minutes_" : ["eftir %n mínútu","eftir %n mínútur"],
    "_%n minute ago_::_%n minutes ago_" : ["fyrir %n mínútu síðan","fyrir %n mínútum síðan"],
    "in a few seconds" : "eftir örfáar sekúndur",
    "seconds ago" : "sekúndum síðan",
    "Empty file" : "Tóm skrá",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Eining með auðkenni: %s er ekki til. Virkjaðu hana í forritastillingum eða hafðu samband við kerfisstjóra.",
    "File is too large to convert" : "Skráin er of stór til að umbreyta henni",
    "Could not convert file" : "Gat ekki umbreytt skrá",
    "Dot files are not allowed" : "Skrár með punkti eru ekki leyfðar",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" er bannað sem heiti á skrá eða möppu.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" er bannað sem forskeyti á skrá eða möppu.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" er ekki leyfilegt innan í heiti á skrá eða möppu.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" er bönnuð skráartegund.",
    "Filenames must not end with \"%1$s\"." : "Skráaheiti mega ekki enda á \"%1$s\".",
    "Invalid parent path" : "Ógild yfirslóð",
    "File already exists" : "Skrá er þegar til",
    "Invalid path" : "Ógild slóð",
    "Failed to create file from template" : "Mistókst að búa til skrá út frá sniðmáti",
    "Templates" : "Sniðmát",
    "Storage %s cannot be moved" : "Ekki er hægt að færa geymslurýmið %s",
    "Path contains invalid segments" : "Slóðin inniheldur ógilda hluta",
    "Filename is a reserved word" : "Skráarheiti er þegar frátekið orð",
    "Filename contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
    "Filename is too long" : "Skráarheiti er of langt",
    "Empty filename is not allowed" : "Autt skráarheiti er ekki leyft.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Ekki er hægt að setja upp \"%s\" forritið vegna þess að ekki var hægt að lesa appinfo-skrána.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Ekki var hægt að setja upp forritið \"%s\" vegna þess að það er ekki samhæft þessari útgáfu vefþjónsins.",
    "__language_name__" : "Íslenska",
    "This is an automatically sent email, please do not reply." : "Þetta er sjálfvirk tölvupóstsending, ekki svara þessu.",
    "Help & privacy" : "Aðstoð og gagnaleynd",
    "Appearance and accessibility" : "Útlit og aðgengi",
    "Apps" : "Forrit",
    "Personal settings" : "Persónulegar stillingar",
    "Administration settings" : "Stillingar stjórnunar",
    "Settings" : "Stillingar",
    "Log out" : "Skrá út",
    "Accounts" : "Notandaaðgangar",
    "Email" : "Tölvupóstur",
    "Mail %s" : "Póstur %s",
    "Fediverse" : "Skýjasamband",
    "View %s on the fediverse" : "Skoða %s á skýjasambandi (fediverse)",
    "Phone" : "Sími",
    "Call %s" : "Hringja í %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Skoða %s á Twitter",
    "Website" : "Vefsvæði",
    "Visit %s" : "Heimsækja %s",
    "Address" : "Vistfang",
    "Profile picture" : "Einkennismynd",
    "About" : "Um hugbúnaðinn",
    "Display name" : "Birtingarnafn",
    "Headline" : "Fyrirsögn",
    "Organization" : "Stofnun/Samtök/Félag",
    "Role" : "Role",
    "Pronouns" : "Fornöfn",
    "Unknown account" : "Óþekktur aðgangur",
    "Additional settings" : "Aukastillingar",
    "Enter the database name for %s" : "Settu inn nafn á gagnagrunni fyrir %s",
    "You cannot use dots in the database name %s" : "Þú mátt ekki nota punkta í gagnagrunnsheitinu %s",
    "You need to enter details of an existing account." : "Þú verður að setja inn auðkenni fyrirliggjandi notandaaðgangs.",
    "Oracle connection could not be established" : "Ekki tókst að koma tengingu á við Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "Fyrir bestu útkomu ættirðu að íhuga að nota GNU/Linux þjón í staðinn.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Það lítur út eins og þessi %s uppsetning sé að keyra á 32-bita PHP umhverfi og að open_basedir hafi verið stillt í php.ini. Þetta mun valda vandamálum með skrár stærri en 4 GB og er stranglega mælt gegn því að þetta sé gert.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjarlægðu stillinguna open_basedir úr php.ini eða skiptu yfir í 64-bita PHP.",
    "Set an admin password." : "Stilltu lykilorð kerfisstjóra.",
    "Cannot create or write into the data directory %s" : "Gat ekki búið til eða skrifað í gagnamöppuna %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Deilingarbakendinn %s verður að vera settur upp fyrir viðmótið OCP\\Share_Backend",
    "Sharing backend %s not found" : "Deilingarbakendinn %s fannst ekki",
    "Sharing backend for %s not found" : "Deilingarbakendi fyrir %s fannst ekki",
    "%1$s shared %2$s with you" : "%1$s deildi %2$s með þér",
    "Open %s" : "Opna %s",
    "%1$s via %2$s" : "%1$s með %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s deildi %2$s með þér og vill bæta við:",
    "%1$s shared %2$s with you and wants to add" : "%1$s deildi %2$s með þér og vill bæta við",
    "%s added a note to a file shared with you" : "%s bætti minnispunkti við skrá sem deilt er með þér",
    "Unknown share type" : "Óþekkt tegund sameignar",
    "You are not allowed to share %s" : "Þú hefur ekki heimild til að deila %s",
    "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
    "Files cannot be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
    "Files cannot be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
    "Expiration date is in the past" : "Gildistíminn er þegar runninn út",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ekki er hægt að setja lokadagsetningu meira en %n dag fram í tímann","Ekki er hægt að setja lokadagsetningu meira en %n daga fram í tímann"],
    "Sharing is only allowed with group members" : "Deiling er aðeins leyfð með meðlimum hópsins",
    "Sharing is disabled" : "Deiling er óvirk",
    "Invalid share recipient" : "Ógildur viðtakandi sameignar",
    "Group \"%s\" does not exist" : "Hópurinn \"%s\" er ekki til",
    "The requested share does not exist anymore" : "Umbeðin sameign er ekki lengur til",
    "The requested share comes from a disabled user" : "Umbeðin sameign kemur frá notanda sem er óvirkur",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Notandinn var ekki búinn til þar sem takmörkum á fjölda notenda var náð. Skoðaðu tilkynningarnar þínar til að sjá meira.",
    "Could not find category \"%s\"" : "Fann ekki flokkinn \"%s\"",
    "Input text" : "Inntakstexti",
    "The input text" : "Inntakstextinn",
    "Sunday" : "Sunnudagur",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Sun." : "Sun.",
    "Mon." : "Mán.",
    "Tue." : "Þri.",
    "Wed." : "Mið.",
    "Thu." : "Fim.",
    "Fri." : "Fös.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Má",
    "Tu" : "Þr",
    "We" : "Mi",
    "Th" : "Fi",
    "Fr" : "Fö",
    "Sa" : "La",
    "January" : "Janúar",
    "February" : "Febrúar",
    "March" : "Mars",
    "April" : "Apríl",
    "May" : "Maí",
    "June" : "Júní",
    "July" : "Júlí",
    "August" : "Ágúst",
    "September" : "September",
    "October" : "Október",
    "November" : "Nóvember",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maí.",
    "Jun." : "Jún.",
    "Jul." : "Júl.",
    "Aug." : "Ágú.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nóv.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Skráðu inn gilt lykilorð",
    "The Login is already being used" : "Innskráningarnafnið er þegar í notkun",
    "Could not create account" : "Gat ekki búið til notandaaðgang",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Einungis eru leyfilegir eftirfarandi stafir í innskráningarnafni: \"a-z\", \"A-Z\", \"0-9\", bil og \"_.@-'\"",
    "A valid Login must be provided" : "Settu inn gilt innskráningarnafn",
    "Login contains whitespace at the beginning or at the end" : "Innskráningarnafnið inniheldur bil í upphafi eða enda",
    "Login must not consist of dots only" : "Innskráningarnafn má ekki einungis samanstanda af punktum",
    "Login is invalid because files already exist for this user" : "Innskráningarnafnið er ógilt vegna þess að þegar eru fyrir hendi skrár sem tilheyra þessum notanda",
    "Account disabled" : "Notandaaðgangur óvirkur",
    "Login canceled by app" : "Forrit hætti við innskráningu",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Ekki var hægt að setja upp \"%1$s\" forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar: %2$s",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Application is not enabled" : "Forrit ekki virkt",
    "Authentication error" : "Villa við auðkenningu",
    "Token expired. Please reload page." : "Kenniteikn er útrunnið. Þú ættir að hlaða síðunni aftur inn.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Engir reklar fyrir gagnagrunn eru uppsettir (sqlite, mysql eða postgresql).",
    "Cannot write into \"config\" directory." : "Get ekki skrifað í \"config\" möppuna.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna. Skoðaðu %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eða, ef þú vilt halda config.php skránni aðeins til lestrar, settu valkostinn \"config_is_read_only\" á 'true' í henni. Skoðaðu %s",
    "Cannot create \"data\" directory." : "Get ekki búið til \"data\" möppu.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Skoðaðu %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Heimildir er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Skoðaðu %s.",
    "Your data directory is not writable." : "Gagnamappn þín er ekki lesanleg.",
    "Setting locale to %s failed." : "Mistókst að setja upp staðfærsluna %s.",
    "Please install one of these locales on your system and restart your web server." : "Settu upp eina af þessum staðfærslum og endurræstu vefþjóninn.",
    "PHP module %s not installed." : "PHP-einingin %s er ekki uppsett.",
    "Please ask your server administrator to install the module." : "Biddu kerfisstjórann þinn um að setja eininguna upp.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-stillingin \"%s\" er ekki sett á \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ef þessi stilling er löguð í php.ini mun Nextcloud keyra aftur",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Búið er að setja upp PHP-einingar, en eru þær ennþá taldar upp eins og þær vanti?",
    "Please ask your server administrator to restart the web server." : "Biddu kerfisstjórann þinn um að endurræsa vefþjóninn.",
    "The required %s config variable is not configured in the config.php file." : "Nauðsynleg %s stillingabreyta er ekki stillt í config.php file.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Biddu kerfisstjórann þinn um að athuga uppsetninguna á Nextcloud.",
    "Your data directory is readable by other people." : "Gagnamappn þín er lesanleg fyrir aðra notendur.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar.",
    "Your data directory must be an absolute path." : "Gagnamappan þín verður að vera með algilda slóð.",
    "Check the value of \"datadirectory\" in your configuration." : "Athugaðu gildi \"datadirectory\" í uppsetningunni þinni.",
    "Your data directory is invalid." : "Gagnamappan þín er ógild.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Gakktu úr skugga um að til staðar sé skrá með heitinu \"%1$s\" í rót gagnageymslunnar. Hún ætti að innihalda eftirfarandi: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Aðgerðin \"%s\" er ekki studd eða útfærð.",
    "Authentication failed, wrong token or provider ID given" : "Auðkenning mistókst, uppgefið rangt teikn eða auðkenni þjónustuveitu",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Breytur vantar til að geta lokið beiðninni. Breytur sem vantar: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Auðkennið \"%1$s\" er þegar notað af skýjasambandsveitunni \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Skýjasambandsveita með auðkennið \"%s\" er ekki til.",
    "Could not obtain lock type %d on \"%s\"." : "Gat ekki fengið læsingu af gerðinni %d á \"%s\".",
    "Storage unauthorized. %s" : "Gagnageymsla ekki auðkennd. %s",
    "Storage incomplete configuration. %s" : "Ófullgerð uppsetning gagnageymslu. %s",
    "Storage connection error. %s" : "Villa í tengingu við gagnageymslu. %s",
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage connection timeout. %s" : "Gagnageymsla féll á tíma. %s",
    "Images" : "Myndir",
    "Transcribe audio" : "Umrita hljóð",
    "Transcribe the things said in an audio" : "Umritaðu það sem sagt er í hljóðspori",
    "Audio input" : "Hljóðinntak",
    "The audio to transcribe" : "Hljóðið sem á að umrita",
    "Transcription" : "Umritun",
    "The transcribed text" : "Umritaði textinn",
    "Confirmation" : "Staðfesting",
    "Chat message" : "Spjallskilaboð",
    "Prompt" : "Kvaðning",
    "Number of images" : "Fjöldi mynda",
    "Chat" : "Spjall",
    "Generates a possible headline for a text." : "Útbýr mögulega fyrirsögn fyrir texta.",
    "Text" : "Texti",
    "Simplify text" : "Einfalda texta",
    "Simplified text" : "Einfaldaður texti",
    "Summarize" : "Gera samantekt",
    "Summary" : "Samantekt",
    "Extract topics" : "Taka út efnisflokka",
    "Topics" : "Umfjöllunarefni",
    "Translate" : "Þýða",
    "Translate text from one language to another" : "Þýddu texta af einu tungumáli yfir á annað",
    "Origin text" : "Upprunalegur texti",
    "The text to translate" : "Textinn sem á að þýða",
    "Origin language" : "Upprunalegt tungumál",
    "The language of the origin text" : "Tungumál upprunalega textans",
    "Target language" : "Marktungumál:",
    "The desired language to translate the origin text in" : "Tungumálið sem þýða skal upprunalega textann yfir á",
    "Result" : "Niðurstöður",
    "The translated text" : "Þýddi textinn",
    "Free prompt" : "Frjáls kvaðning",
    "Runs an arbitrary prompt through the language model." : "Keyrir óreglulega kvaðningu (prompt) í gegnum tungumálslíkanið.",
    "Generate headline" : "Útbúa fyrirsögn",
    "Summarizes text by reducing its length without losing key information." : "Tekur saman aðalatriði texta með því að stytta hann án þess að tapa mikilvægustu upplýsingum.",
    "Extracts topics from a text and outputs them separated by commas." : "Greinir efnisflokka úr texta og aðskilur þá með kommum.",
    "Organisation" : "Stofnun/Félag/Fyrirtæki",
    "File is currently busy, please try again later" : "Skráin er upptekin í augnablikinu, reyndu aftur síðar",
    "Cannot download file" : "Get ekki sótt skrá",
    "Cannot write into \"apps\" directory." : "Get ekki skrifað í \"apps\" möppuna.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í forritamöppuna eða gera App Store forritabúðina óvirka í stillingaskránni. ",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er stillt á <code>%s</code> í stað gildisins \"<code>0</code> eins og vænst var.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Til að laga þetta vandamál ættirðu að setja <code>mbstring.func_overload</code> sem <code>0</code> í php.ini."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
